==> fast_app-1.0.0.tar.gz: lib/fast_app.dart <==
///
/// fast_app.dart
/// fast_app
/// Created by qiuguian on 2019/10/21.
/// Copyright © 2019 fastapp. All rights reserved.
///
/// website: http://www.fastapp.top
///

library fast_app;

//export 'package:flutter/material.dart';
export 'package:fast_app/ui/fast_app_ui.dart';
export 'package:fast_app/net/fast_net.dart';
export 'package:fast_app/theme/fast_theme.dart';
export 'package:fast_app/util/fast_util.dart';
export 'package:fast_app/notice/fast_notification.dart';
export 'package:fast_app/cache/fast_cache.dart';
export 'package:fast_app/fast_app_config.dart';
export  'package:fast_app/util/enum_util.dart';
export  'package:fast_app/util/fast_platform.dart';
export 'package:fast_app/data/fast_data.dart';
export 'package:fast_app/ui/banner/banner_view.dart';
export 'package:flutter_swiper/flutter_swiper.dart';
export 'package:cached_network_image/cached_network_image.dart';
export 'package:fast_app/ui/button/fast_button.dart';
export 'package:fast_app/ui/button/fast_mini_button.dart';
export 'package:fast_app/ui/textfield/fast_row_view.dart';
export 'package:fast_app/ui/textfield/fast_search_view.dart';
export 'package:fast_app/ui/select/fast_select_image_view.dart';
export 'package:fast_app/ui/alert/fast_alert.dart';
export 'package:fast_app/util/fast_theme.dart';
export 'package:fast_app/ui/separator/fast_separator.dart';
export 'package:fast_app/ui/dialog/fast_confirm_dialog.dart';
export 'package:fast_app/ui/button/fast_cutdown_button.dart';
export 'package:fast_app/ui/photo_view/photo_view_page.dart';

==> fast_app-2.0.0.tar.gz: lib/fast_app.dart <==
///
/// fast_app.dart
/// fast_app
/// Created by qiuguian on 2019/10/21.
/// Copyright © 2019 fastapp. All rights reserved.
///
/// website: http://www.fastapp.top
///

library fast_app;

//export 'package:flutter/material.dart';
export 'package:fast_app/ui/fast_app_ui.dart';
export 'package:fast_app/net/fast_net.dart';
export 'package:fast_app/theme/fast_theme.dart';
export 'package:fast_app/util/fast_util.dart';
export 'package:fast_app/notice/fast_notification.dart';
export 'package:fast_app/cache/fast_cache.dart';
export 'package:fast_app/fast_app_config.dart';
export  'package:fast_app/util/enum_util.dart';
export  'package:fast_app/util/fast_platform.dart';
export 'package:fast_app/data/fast_data.dart';
export 'package:fast_app/ui/banner/banner_view.dart';
export 'package:flutter_swiper_null_safety/flutter_swiper_null_safety.dart';
export 'package:cached_network_image/cached_network_image.dart';
export 'package:fast_app/ui/button/fast_button.dart';
export 'package:fast_app/ui/button/fast_mini_button.dart';
export 'package:fast_app/ui/textfield/fast_row_view.dart';
export 'package:fast_app/ui/textfield/fast_search_view.dart';
export 'package:fast_app/ui/select/fast_select_image_view.dart';
export 'package:fast_app/ui/alert/fast_alert.dart';
export 'package:fast_app/util/fast_theme.dart';
export 'package:fast_app/ui/separator/fast_separator.dart';
export 'package:fast_app/ui/dialog/fast_confirm_dialog.dart';
export 'package:fast_app/ui/button/fast_cutdown_button.dart';
export 'package:fast_app/ui/photo_view/photo_view_page.dart';
export 'package:fast_app/getx/base_controller.dart';
